pub enum AttrProblem {
NotInEnum {
allowed: Vec<&'static str>,
actual: String,
},
OutOfRange {
lo: i64,
hi: i64,
actual: i64,
},
OutOfRangeF {
lo: f64,
hi: f64,
actual: f64,
},
WrongType {
expected: &'static str,
},
BadFormat {
reason: &'static str,
},
}Expand description
What is wrong with an attribute value, surfaced inside
AdfSchemaViolation::InvalidAttr.
Variants
NotInEnum
The value is a string but not in the allowed enum.
Fields
OutOfRange
The value is an integer outside the accepted range.
Fields
OutOfRangeF
The value is a number outside the accepted range.
Fields
WrongType
The value’s JSON kind is wrong.
BadFormat
The value is a string but doesn’t satisfy a structured constraint.