pub enum ChangeKind {
Added,
Removed,
Modified,
Unchanged,
Moved,
}Expand description
Coarse change classification.
Variants
Added
Section exists only in to.
Removed
Section exists only in from.
Modified
Section exists on both sides with content edits.
Unchanged
Section exists on both sides at the same position with no content edits.
Moved
Section exists on both sides but at different positions.