install_and_load

Function install_and_load 

pub fn install_and_load(socket: &Path) -> Result<()>
Writes the unit files and enables the socket so systemd listens on the demand socket and spawns the daemon on the first client connect (and at login).