CommitInfoFromCommits

Type Alias CommitInfoFromCommits 

pub type CommitInfoFromCommits = CommitInfo<CommitAnalysisFromCommits>;
Commit information for the commit-message-driven PR path.

Aliased Type

pub struct CommitInfoFromCommits {
    pub hash: String,
    pub author: String,
    pub date: DateTime<FixedOffset>,
    pub original_message: String,
    pub in_main_branches: Vec<String>,
    pub analysis: CommitAnalysisFromCommits,
}

Fields

hash: String

Full SHA-1 hash of the commit.

author: String

Commit author name and email address.

date: DateTime<FixedOffset>

Commit date in ISO format with timezone.

original_message: String

The original commit message as written by the author.

in_main_branches: Vec<String>

Array of remote main branches that contain this commit.

analysis: CommitAnalysisFromCommits

Automated analysis of the commit including type detection and proposed message.