MetricPoint

Type Alias MetricPoint 

pub type MetricPoint = (f64, Option<f64>);
A single (timestamp_ms, value) sample returned by Datadog.

Datadog returns pointlist as a JSON array of two-element arrays where the timestamp is milliseconds since the Unix epoch and the value may be null for gaps in the series.