Drive About API wrapper.
about.get, used solely by drive auth status’s live authentication
check (mirrors crate::gmail::profile_api::ProfileApi, whose
users.getProfile plays the same role for gmail auth status).
Drive About API wrapper.
about.get, used solely by drive auth status’s live authentication
check (mirrors crate::gmail::profile_api::ProfileApi, whose
users.getProfile plays the same role for gmail auth status).