Module commit

Module commit 

Git commit operations and analysis.

Structs

CommitAnalysis
Commit analysis information.
CommitAnalysisForAI
Enhanced commit analysis for AI processing with full diff content.
CommitInfo
Commit information structure, generic over analysis type.
CommitInfoForAI
Commit information with enhanced analysis for AI processing.
FileChange
Individual file change.
FileChanges
File changes statistics.
FileDiffRef
Reference to a per-file diff stored on disk.

Functions

refine_message_scope
Replaces the scope in a conventional commit message with the deterministically resolved scope based on the given files and scope definitions.
resolve_scope
Resolves the best scope for a set of files using scope definition file patterns.