pub enum Selection {
Paths(Vec<PathBuf>),
All {
base: PathBuf,
},
}Expand description
Which worktrees a batch rebase should target.
Variants
Paths(Vec<PathBuf>)
Rebase exactly these worktree folders (each resolved to the worktree that contains it). A path that is the main working tree, is detached, is dirty, or is not a git worktree is reported and skipped, never rebased.
All
Rebase every linked worktree of the repository that contains base
(the process working directory). The main working tree is never included.