check_github_cli

Function check_github_cli 

pub fn check_github_cli(repo_root: &Path) -> Result<()>
Validates that GitHub CLI is available and authenticated.

This checks:

  1. gh CLI is installed and in PATH
  2. User is authenticated (can access the current repo)

Use this at the start of commands that require GitHub API access.

repo_root anchors the repository-access probe to the injected repository rather than the process current working directory.