Module settings

Module settings 

Settings and configuration utilities.

This module provides functionality to read settings from $HOME/.omni-dev/settings.json and use them as a fallback for environment variables.

Structs

Settings
Settings loaded from $HOME/.omni-dev/settings.json.

Functions

get_env_var
Returns an environment variable with fallback to settings.
get_env_vars
Tries multiple environment variables with fallback to settings.