pub fn note_cli_flag_export(key: &str)Expand description
Records that key was exported into the process environment by a
command-line flag, so get_env_var_sourced reports
EnvValueSource::CliFlag for it instead of
EnvValueSource::ProcessEnv.
pub fn note_cli_flag_export(key: &str)Records that key was exported into the process environment by a
command-line flag, so get_env_var_sourced reports
EnvValueSource::CliFlag for it instead of
EnvValueSource::ProcessEnv.