Atlassian Cloud REST API client.
Provides HTTP access to JIRA Cloud REST API v3 for reading and writing issues. Uses Basic Auth (email + API token).
Structs
- Agile
Board - A JIRA agile board.
- Agile
Board List - Result from listing agile boards.
- Agile
Sprint - A JIRA agile sprint.
- Agile
Sprint List - Result from listing agile sprints.
- Atlassian
Client - HTTP client for Atlassian Cloud REST APIs.
- Confluence
Search Result - A Confluence search result.
- Confluence
Search Results - Result from a Confluence CQL search.
- Confluence
User Search Result - A Confluence user in search results.
- Confluence
User Search Results - Result from searching Confluence users.
- Edit
Meta - Metadata returned by
GET /rest/api/3/issue/{key}/editmeta. - Edit
Meta Field - A single field descriptor from the editmeta response.
- Edit
Meta Schema - Schema type information for an editable field.
- Jira
Attachment - A JIRA issue attachment.
- Jira
Changelog Entry - A JIRA issue changelog entry.
- Jira
Changelog Item - A single field change in a changelog entry.
- Jira
Comment - A JIRA issue comment.
- Jira
Created Issue - Result from creating a JIRA issue via the REST API.
- Jira
Custom Field - A JIRA custom field value keyed by both its stable ID and human name.
- Jira
DevBranch - A branch from Jira’s DevStatus API.
- Jira
DevCommit - A commit from Jira’s DevStatus API.
- Jira
DevPull Request - A pull request from Jira’s DevStatus API.
- Jira
DevRepository - A repository from Jira’s DevStatus API.
- Jira
DevStatus - Development status information for a Jira issue.
- Jira
DevStatus Count - Summary counts for a category of development status.
- Jira
DevStatus Summary - High-level development status summary for a Jira issue.
- Jira
Field - A JIRA field definition.
- Jira
Field Option - An option value for a JIRA custom field.
- Jira
Issue - JIRA issue data returned from the REST API.
- Jira
Issue Link - A link on a JIRA issue.
- Jira
Link Type - A JIRA issue link type.
- Jira
Project - A JIRA project.
- Jira
Project List - Result from listing JIRA projects.
- Jira
Search Result - Result from a JIRA JQL search.
- Jira
Transition - A JIRA workflow transition.
- Jira
User - Response from the JIRA
/myselfendpoint. - Jira
Watcher List - Result from listing watchers on a JIRA issue.
- Jira
Worklog - A JIRA issue worklog entry.
- Jira
Worklog List - Result from listing JIRA worklogs.
Enums
- Field
Selection - Selector for which fields to request when fetching a JIRA issue.