pub struct ClaudeClient { /* private fields */ }Expand description
Claude client for commit message improvement
Implementations
Sourceimpl ClaudeClient
impl ClaudeClient
Sourcepub fn new(ai_client: Box<dyn AiClient>) -> Self
pub fn new(ai_client: Box<dyn AiClient>) -> Self
Create new Claude client with provided AI client implementation
Sourcepub fn get_ai_client_metadata(&self) -> AiClientMetadata
pub fn get_ai_client_metadata(&self) -> AiClientMetadata
Get metadata about the AI client
Sourcepub fn from_env(model: String) -> Result<Self>
pub fn from_env(model: String) -> Result<Self>
Create new Claude client with API key from environment variables
Sourcepub async fn generate_amendments(
&self,
repo_view: &RepositoryView,
) -> Result<AmendmentFile>
pub async fn generate_amendments( &self, repo_view: &RepositoryView, ) -> Result<AmendmentFile>
Generate commit message amendments from repository view
Sourcepub async fn generate_amendments_with_options(
&self,
repo_view: &RepositoryView,
fresh: bool,
) -> Result<AmendmentFile>
pub async fn generate_amendments_with_options( &self, repo_view: &RepositoryView, fresh: bool, ) -> Result<AmendmentFile>
Generate commit message amendments from repository view with options
If fresh is true, ignores existing commit messages and generates new ones
based solely on the diff content.
Sourcepub async fn generate_contextual_amendments(
&self,
repo_view: &RepositoryView,
context: &CommitContext,
) -> Result<AmendmentFile>
pub async fn generate_contextual_amendments( &self, repo_view: &RepositoryView, context: &CommitContext, ) -> Result<AmendmentFile>
Generate contextual commit message amendments with enhanced intelligence
Sourcepub async fn generate_contextual_amendments_with_options(
&self,
repo_view: &RepositoryView,
context: &CommitContext,
fresh: bool,
) -> Result<AmendmentFile>
pub async fn generate_contextual_amendments_with_options( &self, repo_view: &RepositoryView, context: &CommitContext, fresh: bool, ) -> Result<AmendmentFile>
Generate contextual commit message amendments with options
If fresh is true, ignores existing commit messages and generates new ones
based solely on the diff content.
Sourcepub async fn generate_pr_content(
&self,
repo_view: &RepositoryView,
pr_template: &str,
) -> Result<PrContent>
pub async fn generate_pr_content( &self, repo_view: &RepositoryView, pr_template: &str, ) -> Result<PrContent>
Generate AI-powered PR content (title + description) from repository view and template
Sourcepub async fn generate_pr_content_with_context(
&self,
repo_view: &RepositoryView,
pr_template: &str,
context: &CommitContext,
) -> Result<PrContent>
pub async fn generate_pr_content_with_context( &self, repo_view: &RepositoryView, pr_template: &str, context: &CommitContext, ) -> Result<PrContent>
Generate AI-powered PR content with project context (title + description)
Sourcepub async fn check_commits(
&self,
repo_view: &RepositoryView,
guidelines: Option<&str>,
include_suggestions: bool,
) -> Result<CheckReport>
pub async fn check_commits( &self, repo_view: &RepositoryView, guidelines: Option<&str>, include_suggestions: bool, ) -> Result<CheckReport>
Check commit messages against guidelines and return a report
Validates commit messages against project guidelines or defaults, returning a structured report with issues and suggestions.
Sourcepub async fn check_commits_with_scopes(
&self,
repo_view: &RepositoryView,
guidelines: Option<&str>,
valid_scopes: &[ScopeDefinition],
include_suggestions: bool,
) -> Result<CheckReport>
pub async fn check_commits_with_scopes( &self, repo_view: &RepositoryView, guidelines: Option<&str>, valid_scopes: &[ScopeDefinition], include_suggestions: bool, ) -> Result<CheckReport>
Check commit messages against guidelines with valid scopes and return a report
Validates commit messages against project guidelines or defaults, using the provided valid scopes for scope validation.