pub struct DefaultConfig {
pub max_output_tokens: usize,
pub input_context: usize,
}Expand description
Default fallback configuration for a provider.
Fields
max_output_tokens: usizeDefault maximum output tokens for unknown models from this provider.
input_context: usizeDefault input context limit for unknown models from this provider.