AI commands.
Structs
- AiCommand
- AI operations.
- Chat
Command - Interactive AI chat session.
Enums
- AiSubcommands
- AI subcommands.
- Output
Format - Output format shared by
sync,clean, andstatus.
Functions
- run_
chat - Sends a single user message to the configured AI and returns the response.
- run_
clean - Cleans Claude skill residue and returns the report as a formatted string.
- run_
status - Reports Claude skill residue.
- run_
sync - Syncs Claude skills and returns the report as a formatted string.
Type Aliases
- Skills
Format - Output format selector for the MCP
claude_skills_*tools.