pub async fn bind_or_reclaim(path: &Path) -> Result<UnixListener>Expand description
Binds the control socket, reclaiming a stale socket from a crashed daemon but refusing to displace a live one.
pub async fn bind_or_reclaim(path: &Path) -> Result<UnixListener>Binds the control socket, reclaiming a stale socket from a crashed daemon but refusing to displace a live one.