pub type CommitInfoFromCommits = CommitInfo<CommitAnalysisFromCommits>;Expand description
Commit information for the commit-message-driven PR path.
Aliased Type
pub struct CommitInfoFromCommits {
pub hash: String,
pub author: String,
pub date: DateTime<FixedOffset>,
pub original_message: String,
pub in_main_branches: Vec<String>,
pub analysis: CommitAnalysisFromCommits,
}Fields
hash: StringFull SHA-1 hash of the commit.
Commit author name and email address.
date: DateTime<FixedOffset>Commit date in ISO format with timezone.
original_message: StringThe original commit message as written by the author.
in_main_branches: Vec<String>Array of remote main branches that contain this commit.
analysis: CommitAnalysisFromCommitsAutomated analysis of the commit including type detection and proposed message.