Module git

Module git 

Git operations and repository management.

Re-exports

pub use amendment::AmendmentHandler;
pub use commit::CommitAnalysis;
pub use commit::CommitAnalysisForAI;
pub use commit::CommitInfo;
pub use commit::CommitInfoForAI;
pub use remote::RemoteInfo;
pub use repository::GitRepository;

Modules

amendment
Git commit amendment operations.
commit
Git commit operations and analysis.
remote
Git remote operations.
repository
Git repository operations.

Constants

FULL_HASH_LEN
Length of a full SHA-1 commit hash in hex characters.
SHORT_HASH_LEN
Number of hex characters to show in abbreviated commit hashes.

Functions

check_git_repo
Checks if the current directory is a git repository.
check_working_directory_clean
Checks if the working directory is clean.