Git commit operations and analysis.
Structs
- Commit
Analysis - Commit analysis information.
- Commit
Analysis ForAI - Enhanced commit analysis for AI processing with full diff content.
- Commit
Info - Commit information structure, generic over analysis type.
- Commit
Info ForAI - Commit information with enhanced analysis for AI processing.
- File
Change - Individual file change.
- File
Changes - File changes statistics.
- File
Diff Ref - Reference to a per-file diff stored on disk.
Functions
- refine_
message_ scope - Replaces the scope in a conventional commit message with the deterministically resolved scope based on the given files and scope definitions.
- resolve_
scope - Resolves the best scope for a set of files using scope definition file patterns.