Git commit operations and analysis.
Structs
- Commit
Analysis - Commit analysis information.
- Commit
Analysis ForAI - Enhanced commit analysis for AI processing with full diff content.
- Commit
Info - Commit information structure, generic over analysis type.
- Commit
Info ForAI - Commit information with enhanced analysis for AI processing.
- File
Change - Individual file change.
- File
Changes - File changes statistics.
- File
Diff Ref - Reference to a per-file diff stored on disk.
- Scope
Count - One scope name with the number of commits that declared it.
- Scope
Usage Report - Report produced by
tally_scope_usage: how declared commit scopes compare against a project’s scope taxonomy.
Functions
- refine_
message_ scope - Replaces the scope in a conventional commit message with the deterministically resolved scope based on the given files and scope definitions.
- resolve_
scope - Resolves the best scope for a set of files using scope definition file patterns.
- tally_
scope_ usage - Tallies declared conventional-commit scopes across
subjects(each the commit’s first message line) against a project’s scope taxonomy.