pub fn branches_containing(
repo: &Repository,
tips: &[MainBranchTip],
commit_oid: Oid,
) -> Result<Vec<String>>Expand description
Returns the display names of the given main branches that contain
commit_oid (the commit is the branch tip or an ancestor of it).