pub fn get(id: &str) -> Option<&'static Resource>
Returns the resource with the given canonical id, or None.
None
Lookup is exact-string and case-sensitive. The omni-dev:// URI scheme must be stripped by the caller before lookup.
omni-dev://