Settings and configuration utilities
This module provides functionality to read settings from $HOME/.omni-dev/settings.json and use them as a fallback for environment variables.
Structs
- Settings
- Settings loaded from $HOME/.omni-dev/settings.json
Functions
- get_
env_ var - Get an environment variable with fallback to settings
- get_
env_ vars - Try multiple environment variables with fallback to settings